@@ -360,7 +360,7 @@ def has_expr(
         fmt_kwargs["stu_eval"] == fmt_kwargs["sol_eval"]):
         fmt_kwargs["stu_eval"] = None
         fmt_kwargs["sol_eval"] = None
-        incorrect_msg = "Expected something different."
+        incorrect_msg = "Ожидалось что-то другое."
 
     # tests ---
     # error in process
